@@ -62,9 +62,11 @@ class PathOverrun(Exception):
 class ProxyProperty(object):
     """A proxy support for access configuration paths as object attributes."""
 
-    def __init__(self, proxy_map):
+    def __init__(self, proxy_map, path, configviper_instance):
         super(ProxyProperty, self).__init__()
         self._proxy_map = proxy_map
+        self._path = [path,]
+        self._configviper_instance = configviper_instance
 
 
     def __repr__(self):
@@ -72,13 +74,49 @@ class ProxyProperty(object):
 
 
     def __getattr__(self, name):
+        
         if not name in self._proxy_map:
-            raise AttributeError('"%s" is unknown' % name)
+            raise AttributeError('"%s%s%s" is unknown' % (
+                    self.path, 
+                    self._configviper_instance.path_separator, 
+                    name,))
 
+        # value will be returned only if full-path to "name" has a converter
         value = self._proxy_map[name]
+        converter = ConfigViper._sv_converters.get(
+                self._fullpath_to(name), None)
+
+        if converter is not None:
+            # return value converted
+            return converter.to_python(value)
+
+        # there's no converter associated to "name";
+        # in that case, if value is a dict return this instance updated
         if isinstance(value, dict):
-            return ProxyProperty(value)
-        return value
+            self._proxy_map = value
+            self._path.append(name)
+            return self
+
+        # value isn't a dict;
+        # return value converted with the default converter
+        converter = self._configviper_instance.get_converter(
+                self._fullpath_to(name))
+
+        return converter.to_python(value)
+
+
+    @property
+    def path(self):
+        """The config-path until current proxy instance."""
+        return self._configviper_instance.path_separator.join(self._path)
+
+
+    def _fullpath_to(self, name):
+        fullpath = name
+        if self._path:
+            fullpath = '%s%s%s' % (self.path, 
+                    self._configviper_instance.path_separator, name,)
+        return fullpath
 
 
 class ConfigViper(object):
@@ -97,6 +135,9 @@ class ConfigViper(object):
     _sv_path_separator = '.'
     """Config-path separator."""
 
+    _sv_converters = {}
+    """Converters dict."""
+
 
     @staticmethod
     def configure(pathname='', filename='', auto_save=True, separator='.'):
@@ -123,6 +164,7 @@ class ConfigViper(object):
         ConfigViper._sv_filename = filename
         ConfigViper._sv_save_on_set = bool(auto_save)
         ConfigViper._sv_path_separator = separator
+        ConfigViper._sv_converters = {}
         
         if not ConfigViper._sv_pathname:
             # set default path name
@@ -137,7 +179,6 @@ class ConfigViper(object):
     def __init__(self):
         super(ConfigViper, self).__init__()
         
-        self._converters_map = {}
         self._config_map = {}
     
         self._pathname = ConfigViper._sv_pathname
@@ -165,10 +206,22 @@ class ConfigViper(object):
         if not name in self._config_map:
             raise AttributeError('"%s" is unknown' % name)
 
+        # value will be returned only if "name" has a converter
         value = self._config_map[name]
+        converter = ConfigViper._sv_converters.get(name, None)
+        if converter is not None:
+            # return value converted
+            return converter.to_python(value)
+
+        # there's no converter associated to "name";
+        # in that case, if value is a dict return a new proxy instance
         if isinstance(value, dict):
-            return ProxyProperty(value)
-        return value
+            return ProxyProperty(value, name, self)
+
+        # value isn't a dict;
+        # return value converted with the default converter
+        converter = self.get_converter(name)
+        return converter.to_python(value)
 
 
     def exists(self, path):
@@ -199,7 +252,7 @@ class ConfigViper(object):
             data = data[name]
     
         # data will end up as { 'd': 3.15 }
-        converter = self._converter_for(path)
+        converter = self.get_converter(path)
         return converter.to_python(data[head])
         
 
@@ -230,7 +283,7 @@ class ConfigViper(object):
         if not isinstance(data, dict):
             raise PathOverrun('"%s" config-path overrun an existing value.' % path)
 
-        converter = self._converter_for(path)
+        converter = self.get_converter(path)
         data[head] = converter.to_json(value)
         
         if self._save_on_set:
@@ -278,7 +331,7 @@ class ConfigViper(object):
         """
 
         # (re)init converters dict
-        self._converters_map = {}
+        ConfigViper._sv_converters = {}
 
         # turn-off auto save on set (will be turned-on again if needed)
         auto_save = self._save_on_set
@@ -286,7 +339,7 @@ class ConfigViper(object):
 
         for path, value, converter in values:
             # first install converter for this config-path
-            self._converters_map[path] = converter
+            ConfigViper._sv_converters[path] = converter
             if self.exists(path):
                 # leave this config-path with current value
                 pass
@@ -314,7 +367,7 @@ class ConfigViper(object):
             current_value = self.get(path) # a Python type
 
         # assign (or replace) converter for config-path
-        self._converters_map[path] = converter
+        ConfigViper._sv_converters[path] = converter
 
         if path_exists:
             # reset the value with the new converter in place
@@ -324,8 +377,11 @@ class ConfigViper(object):
             self.set(path, current_value)
 
 
-    def _converter_for(self, path):
-        converter = self._converters_map.get(path, None)
+    def get_converter(self, path):
+        """Get converter for the given config-path or a
+        :attr:`~converters.DEFAULT_CONVERTER` if there's none.
+        """
+        converter = ConfigViper._sv_converters.get(path, None)
         if converter is None:
             converter = converters.DEFAULT_CONVERTER
         return converter
